@@ -1,6 +1,6 @@
 /*
     lite.* - ngetlite main files
-    Copyright (C) 2000  Matthew Mueller <donut@azstarnet.com>
+    Copyright (C) 2000-2001  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,4 +28,9 @@ char * newstrcpy(char *&dest, const char *src);
 inline void safefree(char *&p){
     if (p){free(p);p=NULL;}
 }
+inline int safestrcmp(const char *a, const char *b){
+    if (!a && !b) return 0;
+    if (!a || !b) return a?1:-1;
+    return strcmp(a,b);
+}
 #endif
