@@ -1,6 +1,6 @@
 /*
     strreps.* - replacements for some string funcs that aren't always available
-    Copyright (C) 1999-2002  Matthew Mueller <donut@azstarnet.com>
+    Copyright (C) 1999-2002  Matthew Mueller <donut AT dakotacom.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,8 @@
 #include "config.h"
 
 #ifndef HAVE_ASPRINTF
-int asprintf(char **str,const char *format,...);
+int asprintf(char **str,const char *format,...)
+        __attribute__ ((format (printf, 2, 3)));
 #endif
 
 #ifndef HAVE_VASPRINTF
@@ -39,7 +40,15 @@ int vasprintf(char **str,const char *format,va_list ap);
 #endif
 
 #ifndef HAVE_STRERROR
-const char * strerror(int err);
+#define NEED_CRAPPY_STRERROR
+const char * crappy_strerror(int err);
+inline const char * strerror(int err) {return crappy_strerror(err);}
+#endif
+//tests if hstrerror might be a define, too, since autoconf can't find that.
+#if (!defined(HAVE_HSTRERROR) && !defined(hstrerror))
+#define NEED_CRAPPY_STRERROR
+const char * crappy_strerror(int err);
+inline const char * hstrerror(int err) {return crappy_strerror(err);}
 #endif
 
 #endif //HAVE_CONFIG_H
